@@ -33,10 +33,10 @@ static void board_nand_hw_init(void)
 	writel(AT91_SMC_SETUP_NWE(1) | AT91_SMC_SETUP_NCS_WR(1) |
 	       AT91_SMC_SETUP_NRD(1) | AT91_SMC_SETUP_NCS_RD(1),
 	       &smc->cs[3].setup);
-	writel(AT91_SMC_PULSE_NWE(2) | AT91_SMC_PULSE_NCS_WR(3) |
+	writel(AT91_SMC_PULSE_NWE(2) | AT91_SMC_PULSE_NCS_WR(4) |
 	       AT91_SMC_PULSE_NRD(2) | AT91_SMC_PULSE_NCS_RD(3),
 	       &smc->cs[3].pulse);
-	writel(AT91_SMC_CYCLE_NWE(5) | AT91_SMC_CYCLE_NRD(5),
+	writel(AT91_SMC_CYCLE_NWE(6) | AT91_SMC_CYCLE_NRD(5),
 	       &smc->cs[3].cycle);
 	writel(AT91_SMC_TIMINGS_TCLR(2) | AT91_SMC_TIMINGS_TADL(7) |
 	       AT91_SMC_TIMINGS_TAR(2)  | AT91_SMC_TIMINGS_TRR(3)   |
@@ -48,32 +48,32 @@ static void board_nand_hw_init(void)
 	       AT91_SMC_MODE_TDF_CYCLE(3),
 	       &smc->cs[3].mode);
 
-	atmel_pio4_set_b_periph(AT91_PIO_PORTA, 22, 0);	/* D0 */
-	atmel_pio4_set_b_periph(AT91_PIO_PORTA, 23, 0);	/* D1 */
-	atmel_pio4_set_b_periph(AT91_PIO_PORTA, 24, 0);	/* D2 */
-	atmel_pio4_set_b_periph(AT91_PIO_PORTA, 25, 0);	/* D3 */
-	atmel_pio4_set_b_periph(AT91_PIO_PORTA, 26, 0);	/* D4 */
-	atmel_pio4_set_b_periph(AT91_PIO_PORTA, 27, 0);	/* D5 */
-	atmel_pio4_set_b_periph(AT91_PIO_PORTA, 28, 0);	/* D6 */
-	atmel_pio4_set_b_periph(AT91_PIO_PORTA, 29, 0);	/* D7 */
+	atmel_pio4_set_b_periph(AT91_PIO_PORTA, 22, ATMEL_PIO_DRVSTR_ME);	/* D0 */
+	atmel_pio4_set_b_periph(AT91_PIO_PORTA, 23, ATMEL_PIO_DRVSTR_ME);	/* D1 */
+	atmel_pio4_set_b_periph(AT91_PIO_PORTA, 24, ATMEL_PIO_DRVSTR_ME);	/* D2 */
+	atmel_pio4_set_b_periph(AT91_PIO_PORTA, 25, ATMEL_PIO_DRVSTR_ME);	/* D3 */
+	atmel_pio4_set_b_periph(AT91_PIO_PORTA, 26, ATMEL_PIO_DRVSTR_ME);	/* D4 */
+	atmel_pio4_set_b_periph(AT91_PIO_PORTA, 27, ATMEL_PIO_DRVSTR_ME);	/* D5 */
+	atmel_pio4_set_b_periph(AT91_PIO_PORTA, 28, ATMEL_PIO_DRVSTR_ME);	/* D6 */
+	atmel_pio4_set_b_periph(AT91_PIO_PORTA, 29, ATMEL_PIO_DRVSTR_ME);	/* D7 */
 	atmel_pio4_set_b_periph(AT91_PIO_PORTB, 2, 0);	/* RE */
 	atmel_pio4_set_b_periph(AT91_PIO_PORTA, 30, 0);	/* WE */
-	atmel_pio4_set_b_periph(AT91_PIO_PORTA, 31, 1);	/* NCS */
-	atmel_pio4_set_b_periph(AT91_PIO_PORTC, 8, 1);	/* RDY */
-	atmel_pio4_set_b_periph(AT91_PIO_PORTB, 0, 1);	/* ALE */
-	atmel_pio4_set_b_periph(AT91_PIO_PORTB, 1, 1);	/* CLE */
+	atmel_pio4_set_b_periph(AT91_PIO_PORTA, 31, ATMEL_PIO_PUEN_MASK);	/* NCS */
+	atmel_pio4_set_b_periph(AT91_PIO_PORTC, 8, ATMEL_PIO_PUEN_MASK);	/* RDY */
+	atmel_pio4_set_b_periph(AT91_PIO_PORTB, 0, ATMEL_PIO_PUEN_MASK);	/* ALE */
+	atmel_pio4_set_b_periph(AT91_PIO_PORTB, 1, ATMEL_PIO_PUEN_MASK);	/* CLE */
 }
 #endif
 
 static void board_usb_hw_init(void)
 {
-	atmel_pio4_set_pio_output(AT91_PIO_PORTB, 12, 1);
+	atmel_pio4_set_pio_output(AT91_PIO_PORTB, 12, ATMEL_PIO_PUEN_MASK);
 }
 
 #ifdef CONFIG_DEBUG_UART_BOARD_INIT
 static void board_uart0_hw_init(void)
 {
-	atmel_pio4_set_c_periph(AT91_PIO_PORTB, 26, 1);	/* URXD0 */
+	atmel_pio4_set_c_periph(AT91_PIO_PORTB, 26, ATMEL_PIO_PUEN_MASK);	/* URXD0 */
 	atmel_pio4_set_c_periph(AT91_PIO_PORTB, 27, 0);	/* UTXD0 */
 
 	at91_periph_clk_enable(ATMEL_ID_UART0);
