@@ -1,14 +1,14 @@
+// SPDX-License-Identifier: GPL-2.0+
 /*
  * Davinci MMC Controller Driver
  *
  * Copyright (C) 2010 Texas Instruments Incorporated
- *
- * SPDX-License-Identifier:	GPL-2.0+
  */
 
 #include <config.h>
 #include <common.h>
 #include <command.h>
+#include <errno.h>
 #include <mmc.h>
 #include <part.h>
 #include <malloc.h>
@@ -30,10 +30,10 @@ static void dmmc_set_clock(struct mmc *mmc, uint clock)
 	struct davinci_mmc_regs *regs = host->reg_base;
 	uint clkrt, sysclk2, act_clock;
 
-	if (clock < mmc->f_min)
-		clock = mmc->f_min;
-	if (clock > mmc->f_max)
-		clock = mmc->f_max;
+	if (clock < mmc->cfg->f_min)
+		clock = mmc->cfg->f_min;
+	if (clock > mmc->cfg->f_max)
+		clock = mmc->cfg->f_max;
 
 	set_val(&regs->mmcclk, 0);
 	sysclk2 = host->input_clk;
@@ -66,7 +66,7 @@ dmmc_wait_fifo_status(volatile struct davinci_mmc_regs *regs, uint status)
 		udelay(100);
 
 	if (wdog == 0)
-		return COMM_ERR;
+		return -ECOMM;
 
 	return 0;
 }
@@ -80,7 +80,7 @@ static int dmmc_busy_wait(volatile struct davinci_mmc_regs *regs)
 		udelay(10);
 
 	if (wdog == 0)
-		return COMM_ERR;
+		return -ECOMM;
 
 	return 0;
 }
@@ -99,7 +99,7 @@ static int dmmc_check_status(volatile struct davinci_mmc_regs *regs,
 			return 0;
 		} else if (mmcstatus & st_error) {
 			if (mmcstatus & MMCST0_TOUTRS)
-				return TIMEOUT;
+				return -ETIMEDOUT;
 			printf("[ ST0 ERROR %x]\n", mmcstatus);
 			/*
 			 * Ignore CRC errors as some MMC cards fail to
@@ -107,7 +107,7 @@ static int dmmc_check_status(volatile struct davinci_mmc_regs *regs,
 			 */
 			if (mmcstatus & MMCST0_CRCRS)
 				return 0;
-			return COMM_ERR;
+			return -ECOMM;
 		}
 		udelay(10);
 
@@ -116,7 +116,7 @@ static int dmmc_check_status(volatile struct davinci_mmc_regs *regs,
 
 	printf("Status %x Timeout ST0:%x ST1:%x\n", st_ready, mmcstatus,
 			get_val(&regs->mmcst1));
-	return COMM_ERR;
+	return -ECOMM;
 }
 
 /*
@@ -346,8 +346,8 @@ static int dmmc_init(struct mmc *mmc)
 	return 0;
 }
 
-/* Set buswidth or clock as indicated by the GENERIC_MMC framework */
-static void dmmc_set_ios(struct mmc *mmc)
+/* Set buswidth or clock as indicated by the MMC framework */
+static int dmmc_set_ios(struct mmc *mmc)
 {
 	struct davinci_mmc *host = mmc->priv;
 	struct davinci_mmc_regs *regs = host->reg_base;
@@ -361,34 +361,31 @@ static void dmmc_set_ios(struct mmc *mmc)
 	/* Set clock speed */
 	if (mmc->clock)
 		dmmc_set_clock(mmc, mmc->clock);
+
+	return 0;
 }
 
+static const struct mmc_ops dmmc_ops = {
+	.send_cmd	= dmmc_send_cmd,
+	.set_ios	= dmmc_set_ios,
+	.init		= dmmc_init,
+};
+
 /* Called from board_mmc_init during startup. Can be called multiple times
  * depending on the number of slots available on board and controller
  */
 int davinci_mmc_init(bd_t *bis, struct davinci_mmc *host)
 {
-	struct mmc *mmc;
+	host->cfg.name = "davinci";
+	host->cfg.ops = &dmmc_ops;
+	host->cfg.f_min = 200000;
+	host->cfg.f_max = 25000000;
+	host->cfg.voltages = host->voltages;
+	host->cfg.host_caps = host->host_caps;
 
-	mmc = malloc(sizeof(struct mmc));
-	memset(mmc, 0, sizeof(struct mmc));
+	host->cfg.b_max = DAVINCI_MAX_BLOCKS;
 
-	sprintf(mmc->name, "davinci");
-	mmc->priv = host;
-	mmc->send_cmd = dmmc_send_cmd;
-	mmc->set_ios = dmmc_set_ios;
-	mmc->init = dmmc_init;
-	mmc->getcd = NULL;
-	mmc->getwp = NULL;
-
-	mmc->f_min = 200000;
-	mmc->f_max = 25000000;
-	mmc->voltages = host->voltages;
-	mmc->host_caps = host->host_caps;
-
-	mmc->b_max = DAVINCI_MAX_BLOCKS;
-
-	mmc_register(mmc);
+	mmc_create(&host->cfg, host);
 
 	return 0;
 }
