@@ -32,7 +32,6 @@
  */
 #define CONFIG_SYS_RX_ETH_BUFFER	0
 #define CONFIG_SYS_FAULT_ECHO_LINK_DOWN
-#define CONFIG_PHY_MARVELL
 
 /*
  * BOOTP options
@@ -52,7 +51,6 @@
  */
 #define CONFIG_SYS_SDRAM_BASE		0xD0000000
 #define CONFIG_SYS_SDRAM_SIZE		0x08000000
-#define CONFIG_NR_DRAM_BANKS		1
 #define CONFIG_MONITOR_IS_IN_RAM
 #define CONFIG_SYS_MONITOR_LEN		0x80000	/* Reserve 512k */
 #define CONFIG_SYS_MONITOR_BASE	(CONFIG_SYS_SDRAM_BASE + \
