@@ -1,7 +1,6 @@
+/* SPDX-License-Identifier: GPL-2.0+ */
 /*
  * Copyright (c) 2017 Intel Corp.
- *
- * SPDX-License-Identifier:	GPL-2.0+
  */
 
 #ifndef __CONFIG_H
@@ -10,7 +9,6 @@
 #include <asm/ibmpc.h>
 
 /* ACPI */
-#define CONFIG_LAST_STAGE_INIT
 
 /* Boot */
 #define CONFIG_BOOTCOMMAND "run bootcmd"
@@ -18,20 +16,15 @@
 /* DISK Partition support */
 
 /* Miscellaneous configurable options */
-#define CONFIG_SYS_LONGHELP
 
 #define CONFIG_SYS_CBSIZE	2048
 #define CONFIG_SYS_MAXARGS	128
 #define CONFIG_SYS_BARGSIZE	CONFIG_SYS_CBSIZE
 
-#define CONFIG_AUTO_COMPLETE
-
 /* Memory */
 #define CONFIG_SYS_LOAD_ADDR			0x100000
 #define CONFIG_PHYSMEM
 
-#define CONFIG_NR_DRAM_BANKS			3
-
 #define CONFIG_SYS_STACK_SIZE			(32 * 1024)
 
 #define CONFIG_SYS_MONITOR_BASE			CONFIG_SYS_TEXT_BASE
